import React from 'react';
import { HeaderGroup } from 'react-table';
import { Div } from '@cloudflare/elements';
import HeaderCell from './HeaderCell';

type Props<Data extends object = {}> = {
  headerGroups: HeaderGroup<Data>[];
  isLoading?: boolean;
  isEmpty?: boolean;
  hasError?: boolean;
  disableHeaders?: boolean;
  selectAllKey?: string;
};

const HeaderRow = <Data extends object = {}>({
  headerGroups,
  isLoading,
  isEmpty,
  hasError,
  disableHeaders,
  selectAllKey
}: Props<Data>) => {
  if (disableHeaders) return null;
  return (
    <Div role="rowgroup" display="block">
      {headerGroups.map((headerGroup, i) => (
        <tr {...headerGroup.getHeaderGroupProps()}>
          {headerGroup.headers.map(column => {
            return (
              <HeaderCell
                key={column.id}
                column={column}
                isLoading={isLoading}
                isEmpty={isEmpty}
                hasError={hasError}
                selectAllKey={selectAllKey}
              />
            );
          })}
        </tr>
      ))}
    </Div>
  );
};

export default HeaderRow;
